LMRuvCOP: Conditional L-moments of the Distribution of U given V

LMRuvCOPR Documentation

Conditional L-moments of the Distribution of U given V

Description

Compute the conditional L-moments of U given a V (the Y direction) through the conditional distribution function G(Y) using the appropriate partial derivative of a copula (\mathbf{C}(u,v)) with respect to V. The inversion of the partial derivative is the conditional quantile function.

Usage

LMRuvCOP(v=seq(0.01, 0.99, by=0.01), cop=NULL, para=NULL, nsim=1E5,
    subdivisions=200L, rel.tol=.Machine$double.eps^0.25, abs.tol=rel.tol, ...)

Arguments

v

Nonexceedance probability v in the Y direction;

cop

A copula function with vectorization as in asCOP;

para

Vector of parameters or other data structures, if needed, to pass to the copula;

nsim

Number of simulations for Monte Carlo integration if numerical integration were to fail;

subdivisions

Argument of same name passed to integrate();

rel.tol

Argument of same name passed to integrate();

abs.tol

Argument of same name passed to integrate(); and

...

Additional arguments to pass to derCOP2.

Value

Value(s) in a list for the median and conditional L-moments given V=v are returned including

median

The conditional median from med.regressCOP2;

L1

The conditional mean \lambda_1|V=v from EuvCOP;

L2

The conditional L-scale \lambda_2|V=v;

T3

The conditional L-skew \tau_3|V=v;

T4

The conditional L-kurtosis \tau_4|V=v;

Author(s)

W.H. Asquith

See Also

EuvCOP, LMRvuCOP, derCOP2

Examples

# Please refer to Examples under LMRvuCOP().

copBasic documentation built on July 23, 2026, 1:07 a.m.