MOcop: The Marshall-Olkin Copula

MOcopR Documentation

The Marshall–Olkin Copula

Description

The Marshall–Olkin copula (Dobrowolski and Kumar, 2014, eq. 2.6; Nelsen, 2006, p. 53), which is also known as the Generalized Cuadras–Augé copula, having parameters \alpha, \beta \in (0,1) is given by

\mathbf{C}_{(\alpha,\beta)}(u,v) = \mathrm{min}(u^{1-\alpha}v, uv^{1-\beta})\mbox{,\ }

and efficiently computed by compound equations for u^\alpha \ge v^\beta

\mathbf{C}_{(\alpha,\beta)}(u,v) = \mathbf{MO}(u,v) = u^{1-\alpha}v\mbox{,}

and for u^\alpha < v^\beta is

\mathbf{C}_{(\alpha,\beta)}(u,v) = \mathbf{MO}(u,v) = uv^{1-\beta}\mbox{.}

As \alpha, \beta \rightarrow 1, the copula limits to the comonotonicity coupla (\mathbf{M}(u,v); M), and as \alpha, \beta \rightarrow 0, the copula limits to the independence copula (\mathbf{\Pi}(u,v); P). The copula can be expected to have a visible singularity as the parameters increase and (or) a simulation size becomes large. The copula with \alpha = \beta is permutation symmetric (isCOP.permsym, breveCOP) and is known as the Cuadras–Augé copula. Spearman Rho (rhoCOP) of the copula is

\rho_\mathbf{C} = 3\alpha\beta / (2\alpha + 2\beta - \alpha\beta)\mbox{,\ }

and Kendall tau (tauCOP) is

\tau_\mathbf{C} = \alpha\beta / (\alpha + \beta - \alpha\beta)\mbox{.}

Parameter estimation using \rho_\mathbf{C} and \tau_\mathbf{C} is problematic because the two statistics are so “correlated” with each other and that either nonunique solutions or nonconverged solutions manifest with simultaneous numerical optimization. Also, application of maximum likelihood (mleCOP) can be problematic because of varying contributions of singularities that the copula can produce. The total contribution of singularity is given by S(u\rightarrow1,v\rightarrow1) = \alpha\beta/ (\alpha + \beta - \alpha\beta), which Nelsen (2006, p. 165) remarks that it is “interesting to note that” Kendall tau is the singular component. Lastly, the L-comoments of copulas (lcomCOP) appear an attractive mechanism for parameter estimation not effected by singularities (refer to Examples). The \mathbf{MO} copula has a role in the three-parameter Gumbel–Hougaard copula copula (GHcop).

Usage

MOcop(u, v, para=NULL, lcomCOP=NULL, ...)

Arguments

u

Nonexceedance probability u in the X direction;

v

Nonexceedance probability v in the Y direction;

para

A vector (single element) of parameters—the \alpha, \beta parameters of the copula;

lcomCOP

A vector containing \rho_\mathbf{C} and the two L-coskews (refer to Examples) from which the parameters are returned; and

...

Additional arguments to pass.

Value

Value(s) for the copula are returned. Otherwise if either lcomCOP is given, then the \alpha, \beta are computed by numerical optimization the the Spearman Rho and the two L-coskews (refer to package lmomco and function lmomco::lcomoms2 for more details) (refer the demonstration of L-comoment parameter estimation in the Examples below).

Author(s)

W.H. Asquith

References

Dobrowolski, E., and Kumar, P., 2014, Some properties of the Marshall–Olkin and generalized Cuadras–Augé families of copula: Australian Journal of Mathematical Analysis and Applications: v. 11, no. 1, art. 2, pp. 1–13, accessed on August 10, 2025, at https://ajmaa.org/searchroot/files/pdf/v11n1/v11i1p2.pdf.

Joe, H., 2014, Dependence modeling with copulas: Boca Raton, CRC Press, 462 p.

See Also

P, taildepCOP

Examples

## Not run: 
  #   **** Demonstration of copula fitting by Method of L-comoments ****
  n    <- 300 # large enough sample size to clearly show L-comoment viability
  UV   <- simCOP(n, cop=MOcop, seed=1, para=c(0.3, 0.7), pch=16, col="seagreen")
  lcm  <- lmomco::lcomoms2(UV) # sample L-comoments (mean off diag. T2 == Spearman Rho)
  sara <- MOcop(lcomCOP=c(mean(diag(lcm$T2[2:1,1:2])), lcm$T3[1,2], lcm$T3[2,1]))
  sara$para <- round(sara$para, digits=8)
  uv   <- simCOP(n, cop=MOcop, seed=1, para=sara$para, col="blue", ploton=FALSE)
  message("MOcop : alpha=", sara$para[1], ", beta=", sara$para[2])
  mara <- mleCOP(UV[,1], v=UV[,2], cop=MOcop, init.para=c(0.2,0.2),
                 parafn=function(x) pnorm(x))
  mara$para <- round(mara$para, digits=8)
  uv   <- simCOP(n, cop=MOcop, seed=1, para=mara$para, col="red", ploton=FALSE)
  message("MOcop : alpha=", mara$para[1], ", beta=", mara$para[2]) #
## End(Not run)

## Not run: 
  # This example developed as a demonstrator of the disarray that the
  # Spearman Footrule measures as a nonunique relation to Spearman Rho.
  # The permutation asymmetry causes the relation between the two to
  # "paint" for positive association as shown in the graphic produced.
  cex <- c(1.3, 1.0, 0.7, 0.4)
  col <- c("#7D0112", "#67C7B1", "#1F28A2", "#CCC86C")
  pch <- c(1, 16, 1, 16)
  plot(c(-0.5, 1), c(0, 1), type="n", xlab="Spearman Footrule", ylab="")
  mtext(paste0("Absolute value of Spearman rho\n",
               "Actual sign is the same as for the Footrule"), side=2, line=2)
  mtext(paste0("Attainable Marshall-Olkin copula, MOcop() with permutation\n",
               "inclusion (breveCOP) and reflections (COP)"), line=1)
  for(r in 1:4) { # reflections, COP
    for(k in seq(-1, 1, by=0.1)) { # permutation asymmetry insertion, breveCOP
      for(a in seq(0, 1, by=0.11)) {   # increment slightly different from beta
        for(b in seq(0, 1, by=0.09)) { # increment slightly different from alpha
          para <- list(cop=MOcop, para=c(a,b), breve=k, reflect=r)
          fotT <- footCOP(cop=breveCOP, para=para)
          rhoT <-  rhoCOP(cop=breveCOP, para=para)
          points(fotT, abs(rhoT), lwd=0.8, pch=pch[r], cex=cex[r], col=col[r])
          #UV <- simCOP(100, cop=breveCOP, para=para)
        }
      }
    }
  } #
## End(Not run)

copBasic documentation built on July 23, 2026, 1:07 a.m.