P: The Product (Independence) Copula

PR Documentation

The Product (Independence) Copula

Description

Compute the product copula (Nelsen, 2006, p. 12), which is defined as

\mathbf{\Pi}(u,v) = uv\mbox{.}

This is the copula of statistical independence between U and V and is sometimes referred to as the independence copula. The two extreme antithesis copulas are the Fréchet–Hoeffding upper-bound (M) and Fréchet–Hoeffding lower-bound (W) copulas.

Usage

P(u, v, ...)

Arguments

u

Nonexceedance probability u in the X direction;

v

Nonexceedance probability v in the Y direction; and

...

Additional arguments to pass.

Value

Value(s) for the copula are returned.

Author(s)

W.H. Asquith

References

Nelsen, R.B., 2006, An introduction to copulas: New York, Springer, 269 p.

See Also

M, W, rhoCOP, lcomCOP, PLcop

Examples

P(c(0.4, 0, 1), c(0, 0.6, 1))

## Not run: 
  # PERFECT INDEPENDENCE
  n <- 100000    # large sample size, L-comoments are zero
  lcomCOP(cop=P) # zeros (numerical integration)
  UV <- simCOP(n=n, cop=P, graphics=FALSE)
  lmomco::lcomoms2(UV, nmom=4)
  # The following are Taus_r^{12} and Taus_r^{21}
  # L-corr:        0.00265 and  0.00264 ---> ZERO
  # L-coskew:     -0.00121 and  0.00359 ---> ZERO
  # L-cokurtosis:  0.00123 and  0.00262 ---> ZERO

  # CONTRAST TO MODEST POSITIVE CORRELATION
  rho   <- 0.6; # Spearman Rho
  theta <- PLACKETTpar(rho=rho)  # Theta = 5.115658
  lcomCOP(cop=PLcop, para=theta) #   Rho = 0.6 and rest zeros
  UV <- simCOP(n=n, cop=PLcop, para=theta, graphics=FALSE)
  lmomco::lcomoms2(UV, nmom=4)
  # The following are Taus_r^{12} and Taus_r^{21}
  # L-corr       0.60303    and  0.60303    ---> Spearman Rho
  # L-coskews    4.5339e-05 and -0.00124011 ---> ZERO
  # L-cokurtosis 0.00088549 and  0.00129812 ---> ZERO
  # Pearson R == Spearman Rho for UV L-comoments 
## End(Not run)

copBasic documentation built on July 23, 2026, 1:07 a.m.