kfuncCOP_Pd: The Kendall (Distribution) Function of d-Dimensional...

kfuncCOP_PdR Documentation

The Kendall (Distribution) Function of d-Dimensional Independence Copula

Description

Compute the Kendall Distribution Function of a d-Dimensional independence copula (P) (Joe, 2014, p. 420):

F_K(z; \mathbf{P}_d) = z + z\sum_k^{d-1} \bigr(-\mathrm{log}(k)\bigr)^k/k!\mbox{,}

where F_K is the nonexceedance probability of joint probability z stemming from \mathbf{P}_d(u_{1, 2, \cdots d}).

Usage

kfuncCOP_Pd(z, d=2)

Arguments

z

The values for z; and

d

Number of d dimensions.

Value

The value(s) for F_K(z; \mathbf{P}_d) is returned.

Note

Though the copBasic is designed for bivariate relations, vining workflows could be used to produce d-dimensional relations from which Kendall functions could be empirically computed from d-variate simulations and a user might want an easy mechanism to look at independence on Kendall distribution function plots.

Author(s)

W.H. Asquith

References

Joe, H., 2014, Dependence modeling with copulas: Boca Raton, CRC Press, 462 p.

See Also

kfuncCOP

Examples

# The 0.50 joint probability has a 0.8465736 nonexceedance probability.
kfuncCOP_Pd(0.50, d=3) # 0.8465736

## Not run: 
  f <- seq(0,1, by=0.01)
  plot(f, kfuncCOP(f, cop=P), type="l", lwd=7, col=grey(0.8),
          xlab="Kendall distribution function (joint probability)",
          ylab="Nonexceedance probability")
  lines(f, kfuncCOP_Pd(f, d=2), lwd=1.5, col="black")
  lines(f, kfuncCOP_Pd(f, d=3), col="seagreen3")
  lines(f, kfuncCOP_Pd(f, d=4), col="seagreen4") # 
## End(Not run)

copBasic documentation built on July 23, 2026, 1:07 a.m.