rN4220cop: The (Reflected) Copula of Equation 4.2.20 of Nelsen's Book

rN4220copR Documentation

The (Reflected) Copula of Equation 4.2.20 of Nelsen's Book

Description

The rN4220 copula (Nelsen, 2006, p. 118; eq. 4.2.20) is named by the author (Asquith) for the copBasic package and is a reflected version of N4220cop defined as

\mathbf{C}_{\mathrm{rN4220}}(u,v; \Theta) = u + v - 1 + \biggl[\mathrm{log}\biggl( \mathrm{exp}\bigl((1-u)^{-\Theta}\bigr) + \mathrm{exp}\bigl((1-v)^{-\Theta}\bigr) - \mathrm{exp}(1)\biggr)\biggr]^{-1/\Theta}\mbox{.}

The \mathbf{rN4220}(u,v) copula is not comprehensive because for \Theta = 0^{+} the copula becomes the independence \mathbf{P}(u,v) copula (P) and as \Theta \rightarrow \infty the copula becomes \mathbf{M}(u,v) (M). The copula is undefined for \Theta < 0. This copula has upper-tail dependency, which is the reverse of the \mathbf{N4220}(u,v) that has lower-tail dependency.

Usage

rN4220cop(u, v, para=NULL, insertM=TRUE, ...)

Arguments

u

Nonexceedance probability u in the X direction;

v

Nonexceedance probability v in the Y direction;

para

A vector (single element) of parameters—the \Theta parameter of the copula;

insertM

For the tail that pinches out towards \mathbf{M}(u,v) (M) use an ad hoc algorithm to insert that copula into the tail (refer to source code) and that algorithm is dependent on the simCOP and the numerical partial derivative inversion for simulation that the package is based around; and

...

Additional arguments to pass.

Value

Value(s) for the copula are returned.

Author(s)

W.H. Asquith

References

Nelsen, R.B., 2006, An introduction to copulas: New York, Springer, 269 p.

Examples

sapply(c(0.1, 1, 10), function(p) rN4220cop(0.4, 0.6, para=p))
# 0.2611771  0.3714941  0.4000000 # perfect correlation controls for p=10
sapply(c(0.1, 1, 10), function(p) rN4220cop(0.2, 0.1, para=p))
# 0.02331165 0.04762172 0.09998847
sapply(c(0.1, 1, 10), function(p)  N4220cop(0.2, 0.1, para=p))
# 0.03549625 0.09993412 0.10000000

copBasic documentation built on July 23, 2026, 1:07 a.m.