wolfCOPtest_drawsim: Draw Simulations of Schweizer and Wolff Sigma Test for Data...

wolfCOPtest_drawsimR Documentation

Draw Simulations of Schweizer and Wolff Sigma Test for Data Having Ties or Censoring

Description

Draw simulations of the Schweizer–Wolff Sigma test and make comparisons to the Kendall Tau and Spearman Rho in the context of ties and (or) the zmat given in the call to wolfCOPtest.

Usage

wolfCOPtest_drawsim(swolf, add=FALSE, alpha=0.05, pdffile=NA,
                           title=NA, ulab="Us", vlab="Vs",
                           mai=c(0.75, 0.75, 0.50, 0.25), ...)

Arguments

swolf

The object from wolfCOPtest that must have the table list element from a trigger of the aslist argument either explicitly or by internal trip. It is necessary that add.cor.tests was set true;

add

If true, then the plot() infrastructure internally is not called but the points(), lines(), and legend() are;

alpha

Statistical significance level alpha to draw a horizontal line on the plot;

pdffile

Name for a pdf file to render if not missing;

title

An optional title of the plot;

ulab

A string to insert in an informational measure of number of unique values in the horizontal U direction below the title. If ulab and vlab are both set missing, then the informational measure is not labeled about the plot;

vlab

A string to insert in an informational measure of number of unique values in the vertical V direction below the title. If ulab and vlab are both set missing, then the informational measure is not labeled about the plot;

mai

Settings for an explicit call to the mai of par(); and

...

Additional arguments to pass (refer to source code).

Value

This function is used for its graphical effects.

Author(s)

W.H. Asquith

See Also

wolfCOPtest

Examples

## Not run: 
  # Example of complete ties in X and Y but the simulation.
  n <- 30; X <- Y <- rep(10, n)
  S <- wolfCOPtest(X,Y, ties.method="random", add.cor.tests=TRUE, rndphi=100)
  wolfCOPtest_drawsim(S); w <- seq(0, 1, by=0.002)
  p <- sapply(w, function(w) wolfCOPtest(w, n)$p.value[2] )
  lines(w, p, lty=2, lwd=2, col="firebrick") # This line plots on top of prior black
  # line that is a requirement if all the algorithms are working as advertised. 
## End(Not run)

copBasic documentation built on Oct. 5, 2026, 9:06 a.m.