Generate a gridded representation of the bivariate empirical copula (see EMPIRcop, Salvadori et al., 2007, p. 140). Herein, the \(\ddot{\mathbf{C}}_n\) (double-dots) are used to denote gridding of the copula. This function has the primary intention of supporting 3-D renderings or 2-D images of the copulatic surface, but many empirical copula functions in copBasic rely on the grid of the empirical copula---unlike the functions that support parametric copulas. The algorithm within EMPIRgrid is slow because of nested loops, but a vastly faster version with some tweaks (not having an explicit deluv) is available under EMPIRgrid_fast.
EMPIRgrid(para=NULL, deluv=0.05, gridonly=FALSE, verbose=FALSE, ...)A matrix is returned (\(\ddot{\mathbf{C}}_{n}(u,v)\)), if gridonly is true. Otherwise a list of the \(u\), \(v\), and \(\ddot{\mathbf{C}}_{n}(u,v)\) or other definitions (ctype for EMPIRcop) is returned. The list will also contain the deluv used to generate the grid and if the user passed through ... the ctype for EMPIRcop, then that is preserved, otherwise set at "unknown". The list is returned as classes of "empirical.copula.grid" and "list". This is classification might be used in copBasic to check for a grid in other functions.
A matrix of \(u\) and \(v\) vectors as an alternative to uv for syntax compatibility for other situations in copBasic;
A delta value of the both the \(u\) and \(v\) axes (grid edges) for empirical copula estimation by the EMPIRcop function;
A logical to return the empcop component (\(\ddot{\mathbf{C}}_{n}(u,v)\)) passed through ... the ctype for EMPIRcop;
A logical controlling whether the progress during grid building is to be shown; and
Additional arguments to pass to EMPIRcop.
W.H. Asquith
Salvadori, G., De Michele, C., Kottegoda, N.T., and Rosso, R., 2007, Extremes in Nature---An approach using copulas: Springer, 289 p.
EMPIRcop, EMPIRgrid_fast, EMPIRgrid_lkup, EMPIRcopdf