Generate a fast gridded representation of the bivariate empirical copula (Hernández-Maldonado et al., 2024). Mathematics for the "1/n" and "bernstein" copula are shown under EMPIRcop. Herein, the \(\ddot{\mathbf{C}}_n\) (double-dots) are used to denote gridding of the copula. This function is a much more recent addition (spring 2026) to the copBasic than its historical ancestor of EMPIRgrid because of publication of the algorithm by Hernández-Maldonado et al. (2024). The copBasic author personally thanks V.M. Hernández-Maldonado for a May 2026 discussion on the algorithm and some clarifications to the pseudo-code in Hernández-Maldonado et al. (2024).
EMPIRgrid_fast(uv=NULL, ctype=c("1/n", "bernstein"), para=NULL,
gridonly=FALSE, verbose=FALSE, ...)A matrix is returned (\(\ddot{\mathbf{C}}_{n}(u,v)\) or \(\ddot{\mathbf{C}}^\mathcal{B}_n(u,v)\)), if gridonly is true. Otherwise a list of the \(u\), \(v\), and \(\ddot{\mathbf{C}}_{n}(u,v)\) or \(\ddot{\mathbf{C}}^\mathcal{B}_n(u,v)\) is returned. The list will also contain the deluv (simply \(1/n\) for sample size \(n\)) used and the ctype. The list is returned as classes of "empirical.copula.grid" and "list". This is classification might be used in copBasic to check for a grid in other functions. Note, there is no deluv argument to this function like there is for the historical function EMPIRgrid.
A data frame or matrix of \(u\) and \(v\) vectors of nonexceedance probabilities (see also para);
A means to trigger which definition of empirical copula is to be used: \(\mathbf{C}_n(u,v)\) ("1/n") or \(\mathbf{C}^\mathcal{B}_n(u,v)\) ("bernstein");
A matrix of \(u\) and \(v\) vectors as an alternative to uv for syntax compatibility for other situations in copBasic;
A logical controlling whether the progress during grid building is to be shown;
A logical to return the empcop component (\(\ddot{\mathbf{C}}_{n}(u,v)\) or \(\ddot{\mathbf{C}}^\mathcal{B}_n(u,v)\)); and
Additional arguments to pass to EMPIRcop.
W.H. Asquith
Hernández-Maldonado, V.M., Erdely, A., Díaz-Viera, M., and Rios, L., 2024, Fast procedure to compute empirical and Bernstein copulas: Applied Mathematics and Computation, v. 477, article 128827, 14 p., tools:::Rd_expr_doi("10.1016/j.amc.2024.128827").
EMPIRgrid, EMPIRgrid_lkup