Compute joint probability through a gridded empirical copula \(\mathbf{C}_n(u,v)\) using bilinear interpolation (vectorized, no for looping). The function is designed to act like EMPIRcop, but in lieu of consuming the bivariate data in para argument, the EMPIRgrid_lkup operates off a precomputed gridded list representation of the empirical copula computed either from EMPIRgrid (legacy) or EMPIRgrid_fast. Given a gridded empirical copula denoted as \(\ddot{\mathbf{C}}_n\) and bounding cells of a rectangle \(11\) (lower left), \(12\) (lower right), \(21\) (upper left), and \(22\), the \(\mathbf{C}_n(u,v)\) can be estimated by bilinear interpolation in a weighted mean form as:
$$\mathbf{C}_n(u,v) \approx w_{11}\times\ddot{\mathbf{C}}_{11} + w_{12}\times\ddot{\mathbf{C}}_{12} + w_{21}\times\ddot{\mathbf{C}}_{21} + w_{22}\times\ddot{\mathbf{C}}_{22}\text{,}$$ for which the weights are $$w_{11} = \frac{(u_2 - u )(v_2 - v )}{(u_2 - u_1)(v_2 - v_1)}\text{,\ } w_{12} = \frac{(u_2 - u )(v - v_1)}{(u_2 - u_1)(v_2 - v_1)}\text{,}$$ $$w_{21} = \frac{(u - u_1)(v_2 - v )}{(u_2 - u_1)(v_2 - v_1)}\text{,\ and\ } w_{22} = \frac{(u - u_1)(v - v_1)}{(u_2 - u_1)(v_2 - v_1)}\text{.}$$
EMPIRgrid_lkup(u, v, para=NULL, ...)Value(s) for the copula are returned.
Nonexceedance probability \(u\) in the \(X\) direction;
Nonexceedance probability \(v\) in the \(Y\) direction;
A gridded empirical data structure from EMPIRgrid and EMPIRgrid_fast; and
Additional arguments to pass to EMPIRgrid_fast if para is null.
W.H. Asquith
EMPIRgrid, EMPIRgrid_fast