| LMRuvCOP | R Documentation |
Compute the conditional L-moments of U given a V (the Y direction) through the conditional distribution function G(Y) using the appropriate partial derivative of a copula (\mathbf{C}(u,v)) with respect to V. The inversion of the partial derivative is the conditional quantile function.
LMRuvCOP(v=seq(0.01, 0.99, by=0.01), cop=NULL, para=NULL, nsim=1E5,
subdivisions=200L, rel.tol=.Machine$double.eps^0.25, abs.tol=rel.tol, ...)
v |
Nonexceedance probability |
cop |
A copula function with vectorization as in |
para |
Vector of parameters or other data structures, if needed, to pass to the copula; |
nsim |
Number of simulations for Monte Carlo integration if numerical integration were to fail; |
subdivisions |
Argument of same name passed to |
rel.tol |
Argument of same name passed to |
abs.tol |
Argument of same name passed to |
... |
Additional arguments to pass to |
Value(s) in a list for the median and conditional L-moments given V=v are returned including
median |
The conditional median from |
L1 |
The conditional mean |
L2 |
The conditional L-scale |
T3 |
The conditional L-skew |
T4 |
The conditional L-kurtosis |
W.H. Asquith
EuvCOP, LMRvuCOP, derCOP2
# Please refer to Examples under LMRvuCOP().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.