Compute the conditional L-moments of \(U\) given a \(V\) (the \(Y\) direction) through the conditional distribution function \(G(Y)\) using the appropriate partial derivative of a copula (\(\mathbf{C}(u,v)\)) with respect to \(V\). The inversion of the partial derivative is the conditional quantile function.
LMRuvCOP(v=seq(0.01, 0.99, by=0.01), cop=NULL, para=NULL, nsim=1E5,
subdivisions=200L, rel.tol=.Machine$double.eps^0.25, abs.tol=rel.tol, ...)Value(s) in a list for the median and conditional L-moments given \(V=v\) are returned including
The conditional median from med.regressCOP2;
The conditional mean \(\lambda_1|V=v\) from EuvCOP;
The conditional L-scale \(\lambda_2|V=v\);
The conditional L-skew \(\tau_3|V=v\);
The conditional L-kurtosis \(\tau_4|V=v\);
Nonexceedance probability \(v\) in the \(Y\) direction;
A copula function with vectorization as in asCOP;
Vector of parameters or other data structures, if needed, to pass to the copula;
Number of simulations for Monte Carlo integration if numerical integration were to fail;
Argument of same name passed to integrate();
Argument of same name passed to integrate();
Argument of same name passed to integrate(); and
Additional arguments to pass to derCOP2.
W.H. Asquith
EuvCOP, LMRvuCOP, derCOP2
# Please refer to Examples under LMRvuCOP().
Run the code above in your browser using DataLab