Compute the conditional L-moments of \(V\) given a \(U\) (the \(X\) direction) through the conditional distribution function \(F(X)\) using the appropriate partial derivative of a copula (\(\mathbf{C}(u,v)\)) with respect to \(U\). The conditional L-moments are computed for \(\lambda_1\) (mean) from EvuCOP (refer to mathematics therein) and for \(r \ge 2\) are computed by
$$\lambda_r = \int_0^1 F(k) \times (1-F(k)) \times L_r(F(k))\,\mathrm{d}k\mbox{,}$$
where \(F(k)\) becomes replaced in copBasic with the conditional distribution function of a copula by Nelsen (2006, pp. 13, 40--41) with respect to \(u\):
$$0 \le \frac{\delta}{\delta u} \mathbf{C}(u,v) \le 1\mbox{,}$$
which is derCOP and \(L_r(u)\) is defined (Jones, 2004; Asquith, 2011) as
$$L_r(z) = \frac{1}{r-1}\sum_{j=0}^{r-2} (-1)^j {r-1 \choose j}{r-1 \choose j+1}z^{r-2-j}(1-z)^j\mbox{.}$$
Asquith (2011) mistakenly lists the leading multiplier \(1/(1-r)\) in lieu of \(1/(1-r)\) (correct) as shown above; the lmomco package contains a suitable errata as discovered in copBasic development for LMRvuCOP and LMRuvCOP.
LMRvuCOP(u=seq(0.01, 0.99, by=0.01), cop=NULL, para=NULL, nsim=1E5,
subdivisions=200L, rel.tol=.Machine$double.eps^0.25, abs.tol=rel.tol, ...)Value(s) in a list for the median and conditional L-moments given \(U=u\) are returned including
The conditional median from med.regressCOP;
The conditional mean \(\lambda_1|U=u\) from EvuCOP;
The conditional L-scale \(\lambda_2|U=u\);
The conditional L-skew \(\tau_3|U=u\);
The conditional L-kurtosis \(\tau_4|U=u\);
Nonexceedance probability \(u\) in the \(X\) direction;
A copula function with vectorization as in asCOP;
Vector of parameters or other data structures, if needed, to pass to the copula;
Number of simulations for Monte Carlo integration if numerical integration were to fail;
Argument of same name passed to integrate();
Argument of same name passed to integrate();
Argument of same name passed to integrate(); and
Additional arguments to pass to derCOP.
W.H. Asquith
Asquith, W.H., 2011, Distributional analysis with L-moment statistics using the R environment for statistical computing: Createspace Independent Publishing Platform, ISBN 978--146350841--8.
Jones, M.C., 2004, On some expressions for variance, covariance, skewness and L-moments: Journal of Statistical Planning and Inference, v.126, pp. 97--106, tools:::Rd_expr_doi("10.1016/j.jspi.2003.09.001").
Nelsen, R.B., 2006, An introduction to copulas: New York, Springer, 269 p.
EvuCOP, LMRuvCOP, derCOP