| N4220cop | R Documentation |
The N4220 copula (Nelsen, 2006, p. 118; eq. 4.2.20) is named by the author (Asquith) for the copBasic package and is defined as
\mathbf{C}_{\mathrm{N4220}}(u,v; \Theta) = \biggl[\mathrm{log}\biggl( \mathrm{exp}\bigl(u^{-\Theta}\bigr) +
\mathrm{exp}\bigl(v^{-\Theta}\bigr) -
\mathrm{exp}(1)\biggr)\biggr]^{-1/\Theta}\mbox{.}
The \mathbf{N4220}(u,v) copula is not comprehensive because for \Theta = 0^{+} the copula becomes the independence \mathbf{P}(u,v) copula (P) and as \Theta \rightarrow \infty the copula becomes \mathbf{M}(u,v) (M). The copula is undefined for \Theta < 0. This copula has lower-tail dependency, which is the reverse of the \mathbf{rN4220}(u,v) that has uppr-tail dependency. Hence, a reflected (refer to COP, reflect=2) version of this copula is natively supported as the rN4220cop to put the tail dependency into the upper-right corner and more “hydrologic-system like.”
N4220cop(u, v, para=NULL, insertM=TRUE, ...)
u |
Nonexceedance probability |
v |
Nonexceedance probability |
para |
A vector (single element) of parameters—the |
insertM |
For the tail that pinches out towards |
... |
Additional arguments to pass. |
Value(s) for the copula are returned.
W.H. Asquith
Nelsen, R.B., 2006, An introduction to copulas: New York, Springer, 269 p.
sapply(c(0.1, 1, 10), function(p) N4220cop(0.4, 0.6, para=p))
# 0.2611771 0.3714941 0.4000000 # perfect correlation controls for p=10
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.