| TRIcop | R Documentation |
The Triangular copula (Nelsen, 2006, exam. 3.3, pp. 59–60; exer. 3.7, pp. 64–65) is
\mathbf{C}_{\Theta}(u,v) = \mathbf{TRI}(u,v)
for \Theta \in (0,-1). The copula, as \Theta \rightarrow 0 limits, to the countermonotonicity coupla (\mathbf{W}(u,v); W), as \Theta \rightarrow 1 limits to the comonotonicity copula (\mathbf{M}(u,v); M). The parameter \Theta is readily computed from a Spearman Rho (rhoCOP) or Kendall Tau (tauCOP) by \rho_\mathbf{C} = \tau_\mathbf{C} = 2\Theta-1. However in general for finite samples, the sample versions of Spearman Rho and Kendall Tau will not be equal and different \Theta wil result.
TRIcop(u, v, para=NULL, rhotau=NULL, ...)
u |
Nonexceedance probability |
v |
Nonexceedance probability |
para |
A vector (single element) of parameters—the |
rhotau |
Optional Spearman Rho or Kendall Tau; and |
... |
Additional arguments to pass. |
Value(s) for the copula are returned. Otherwise if rhotau is given, then the \Theta is computed and a list having
para |
The parameter |
rhotau |
Spearman Rho or Kendall Tau. |
and if para=NULL and rhotau=NULL, then the values within u and v are used to compute Spearman Rho or Kendall Tau and then compute the parameter, and these are returned in the aforementioned list.
W.H. Asquith
Nelsen, R.B., 2006, An introduction to copulas: New York, Springer, 269 p.
M, W
# Concerning Nelsen (2006, exer. 5.6, p. 171)
rhoCOP(cop=TRIcop, para=0.25) # -0.4999916
tauCOP(cop=TRIcop, para=0.25) # -0.5
## Not run:
for(i in seq_len(4)) {
para <- list(cop=TRIcop, para=0.25, reflect=i)
uv <- simCOP(100, cop=COP, para=para, seed=1, col=i, ploton=! as.logical(i-1))
} #
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.