The Triangular copula (Nelsen, 2006, exam. 3.3, pp. 59--60; exer. 3.7, pp. 64--65) is
$$\mathbf{C}_{\Theta}(u,v) = \mathbf{TRI}(u,v)$$ for \(\Theta \in (0,-1)\). The copula, as \(\Theta \rightarrow 0\) limits, to the countermonotonicity coupla (\(\mathbf{W}(u,v)\); W), as \(\Theta \rightarrow 1\) limits to the comonotonicity copula (\(\mathbf{M}(u,v)\); M). The parameter \(\Theta\) is readily computed from a Spearman Rho (rhoCOP) or Kendall Tau (tauCOP) by \(\rho_\mathbf{C} = \tau_\mathbf{C} = 2\Theta-1\). However in general for finite samples, the sample versions of Spearman Rho and Kendall Tau will not be equal and different \(\Theta\) wil result.
TRIcop(u, v, para=NULL, rhotau=NULL, ...)Value(s) for the copula are returned. Otherwise if rhotau is given, then the \(\Theta\) is computed and a list having
The parameter \(\Theta\), and
Spearman Rho or Kendall Tau.
and if para=NULL and rhotau=NULL, then the values within u and v are used to compute Spearman Rho or Kendall Tau and then compute the parameter, and these are returned in the aforementioned list.
Nonexceedance probability \(u\) in the \(X\) direction;
Nonexceedance probability \(v\) in the \(Y\) direction;
A vector (single element) of parameters---the \(\Theta\) parameter of the copula;
Optional Spearman Rho or Kendall Tau; and
Additional arguments to pass.
W.H. Asquith
Nelsen, R.B., 2006, An introduction to copulas: New York, Springer, 269 p.
M, W