| rN4220cop | R Documentation |
The rN4220 copula (Nelsen, 2006, p. 118; eq. 4.2.20) is named by the author (Asquith) for the copBasic package and is a reflected version of N4220cop defined as
\mathbf{C}_{\mathrm{rN4220}}(u,v; \Theta) = u + v - 1 + \biggl[\mathrm{log}\biggl( \mathrm{exp}\bigl((1-u)^{-\Theta}\bigr) +
\mathrm{exp}\bigl((1-v)^{-\Theta}\bigr) -
\mathrm{exp}(1)\biggr)\biggr]^{-1/\Theta}\mbox{.}
The \mathbf{rN4220}(u,v) copula is not comprehensive because for \Theta = 0^{+} the copula becomes the independence \mathbf{P}(u,v) copula (P) and as \Theta \rightarrow \infty the copula becomes \mathbf{M}(u,v) (M). The copula is undefined for \Theta < 0. This copula has upper-tail dependency, which is the reverse of the \mathbf{N4220}(u,v) that has lower-tail dependency.
rN4220cop(u, v, para=NULL, insertM=TRUE, ...)
u |
Nonexceedance probability |
v |
Nonexceedance probability |
para |
A vector (single element) of parameters—the |
insertM |
For the tail that pinches out towards |
... |
Additional arguments to pass. |
Value(s) for the copula are returned.
W.H. Asquith
Nelsen, R.B., 2006, An introduction to copulas: New York, Springer, 269 p.
sapply(c(0.1, 1, 10), function(p) rN4220cop(0.4, 0.6, para=p))
# 0.2611771 0.3714941 0.4000000 # perfect correlation controls for p=10
sapply(c(0.1, 1, 10), function(p) rN4220cop(0.2, 0.1, para=p))
# 0.02331165 0.04762172 0.09998847
sapply(c(0.1, 1, 10), function(p) N4220cop(0.2, 0.1, para=p))
# 0.03549625 0.09993412 0.10000000
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.