Data for the test components for small samples. Empirical sampling distributions of Schweizer--Wolff Sigma (\(\hat\sigma_\mathbf{C}\), wolfCOP) for \(n \in 3, \cdots, 40\) of the \(\mathrm{NULL} : \mathbf{C} = \mathbf{\Pi}\) (Independence copula, P), where \(\sigma_\mathbf{C}\) is defined under wolfCOP, using simulation sizes of 900,000 for each \(n\). So, total simulation size was 34,200,000. Continuing, this data set is a concatenated table of empirical distributions formed from the unique number of \(\hat\sigma_\mathbf{C}\) (discrete variables in small samples), which large-simulation attainable up to \(\pm4.26\) standard deviations, were computed and tabulated in the wolfCOPtest_data_smlsam table. Algorithms for the small-sample components are located at inst/make_wolfCOPtest/smlsam/make_wolfCOPtestP_smlsam.R, and this script is the origin of the \(n = 40\) in wolfCOPtest source code.
For the smallest of sample sizes, the empirical distribution is a step function, and for each plateau, a nudge using .Machine$double.eps has been used to make approx() for sensible in wolfCOPtest. In the Examples herein, the jaggedness of the empirical distribution can readily be seen and visually smoothing by about \(n > 10\). Finally, the wolfCOPtest function internally loads the wolfCOPtest_data_smlsam tables, and most users will not need to access this dataset themselves unless for curiosity.
data(wolfCOPtest_data_smlsam)An R data.frame titled wolfCOPtest_data_smlsam with
Sample size;
Nonexceedance probability of empirical distribution of \(\hat\sigma_\mathbf{C}\) (wolfCOP). Note, quantile(..., type=4) was used for computations because of structural similarity to sample \(\hat\sigma_\mathbf{C}\) as implemented in copBasic;
Value for \(\hat\sigma_\mathbf{C}\) (wolfCOP);
wolfCOPtest