| wolfCOPtest_drawsim | R Documentation |
Draw simulations of the Schweizer–Wolff Sigma test and make comparisons to the Kendall Tau and Spearman Rho in the context of ties and (or) the zmat given in the call to wolfCOPtest.
wolfCOPtest_drawsim(swolf, add=FALSE, alpha=0.05, pdffile=NA,
title=NA, ulab="Us", vlab="Vs",
mai=c(0.75, 0.75, 0.50, 0.25), ...)
swolf |
The object from |
add |
If true, then the |
alpha |
Statistical significance level alpha to draw a horizontal line on the plot; |
pdffile |
Name for a pdf file to render if not missing; |
title |
An optional title of the plot; |
ulab |
A string to insert in an informational measure of number of unique values in the horizontal |
vlab |
A string to insert in an informational measure of number of unique values in the vertical |
mai |
Settings for an explicit call to the |
... |
Additional arguments to pass (refer to source code). |
This function is used for its graphical effects.
W.H. Asquith
wolfCOPtest
## Not run:
# Example of complete ties in X and Y but the simulation.
n <- 30; X <- Y <- rep(10, n)
S <- wolfCOPtest(X,Y, ties.method="random", add.cor.tests=TRUE, rndphi=100)
wolfCOPtest_drawsim(S); w <- seq(0, 1, by=0.002)
p <- sapply(w, function(w) wolfCOPtest(w, n)$p.value[2] )
lines(w, p, lty=2, lwd=2, col="firebrick") # This line plots on top of prior black
# line that is a requirement if all the algorithms are working as advertised.
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.